==> jboss-dv-6.1.3.redhat-1-sources.zip: dv-6.1.3-src/teiid-parent-8.7.4.redhat-1/connectors/translator-jdbc/src/main/java/org/teiid/translator/jdbc/ParseFormatFunctionModifier.java <==
/*
 * JBoss, Home of Professional Open Source.
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

package org.teiid.translator.jdbc;

import java.util.Arrays;
import java.util.List;

import org.teiid.language.Function;
import org.teiid.language.Literal;

public abstract class ParseFormatFunctionModifier extends FunctionModifier {
	
	private String prefix;
	
	public ParseFormatFunctionModifier(String prefix) {
		this.prefix = prefix;
	}
	
	@Override
	public List<?> translate(Function function) {
		if (!(function.getParameters().get(1) instanceof Literal)) {
			return null; //shouldn't happen
		}
		Literal l = (Literal)function.getParameters().get(1);
		return Arrays.asList(prefix, function.getParameters().get(0), ", ", translateFormat((String) l.getValue()), ")" ); //$NON-NLS-1$ //$NON-NLS-2$
	}

	abstract protected Object translateFormat(String format);
}

==> jboss-dv-6.2.7.redhat-1-sources.zip: dv-6.2.7-src/teiid-parent-8.7.8.6_2-redhat-1/connectors/translator-jdbc/src/main/java/org/teiid/translator/jdbc/ParseFormatFunctionModifier.java <==
/*
 * JBoss, Home of Professional Open Source.
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

package org.teiid.translator.jdbc;

import java.util.ArrayList;
import java.util.List;

import org.teiid.language.Expression;
import org.teiid.language.Function;
import org.teiid.language.Literal;

public abstract class ParseFormatFunctionModifier extends FunctionModifier {
	
	private String prefix;
	
	public ParseFormatFunctionModifier(String prefix) {
		this.prefix = prefix;
	}
	
	@Override
	public List<?> translate(Function function) {
		if (!(function.getParameters().get(1) instanceof Literal)) {
			return null; //shouldn't happen
		}
		Literal l = (Literal)function.getParameters().get(1);
		List<Object> result = new ArrayList<Object>();
		result.add(prefix);
		translateFormat(result, function.getParameters().get(0), (String)l.getValue());
		result.add(")"); //$NON-NLS-1$
		return result; 
	}

	protected void translateFormat(List<Object> result, Expression expression,
			String value) {
		result.add(expression);
		result.add(", "); //$NON-NLS-1$
		result.add(translateFormat(value));
	}

	abstract protected Object translateFormat(String format);
}
